RadarArgs

Struct RadarArgs 

pub struct RadarArgs {
    pub features: Option<Vec<RadarImageFeature>>,
    pub radar_types: Option<Vec<RadarType>>,
    pub remove_header: bool,
    pub force: bool,
    pub create_png: bool,
    pub create_apng: bool,
    pub open_mpv: bool,
    pub frame_delay_ms: Option<u16>,
    pub max_frames: Option<u64>,
    pub image_dir: Option<PathBuf>,
    pub mpv_ipc_dir: Option<PathBuf>,
    pub monitor: bool,
}

Fields

features: Option<Vec<RadarImageFeature>>

Can be specified multiple times

radar_types: Option<Vec<RadarType>>

Can be specified multiple times

remove_header: bool

Remove the header at the top of each image

force: bool

Re-generate images that already exist

create_png: bool

Create PNG files for each radar image

create_apng: bool

Combine all images into an animated PNG file

open_mpv: bool

View the images as a loop in MPV

frame_delay_ms: Option<u16>

Time between each frame in milliseconds (applies to APNG and MPV)

max_frames: Option<u64>

Maximum amount of frames to create

image_dir: Option<PathBuf>

Output directory for image files

mpv_ipc_dir: Option<PathBuf>monitor: bool

Run continuously and fetch new radar images when available